@@ -7,10 +7,27 @@ DEFAULT_CONFIG = {
     'MAX_CONTENT_LENGTH': 1073741824,
     'SQLALCHEMY_TRACK_MODIFICATIONS': False,
     'TRACK_USER_INTERACTION': False,
-    'DOMAIN_NAME': 'localhost'
+    'TRACK_CREDITS': False,
+    'DOMAIN_NAME': 'localhost',
+    'LOGIN_INSTRUCTIONS': None,
+    'SIGN_UP_INSTRUCTIONS': None,
+    'SIGN_UP_ASK_SOCIAL_MEDIA': False,
+    'PRIVACY_POLICY_PAGE': None
 }
 
 
+def _read_if_html_path(txt: str) -> str:
+    """Open HTML file if path provided
+
+    If the input is a path to a valid HTML file, read it.
+    Otherwise return the input
+    """
+    if txt and txt.endswith('.html'):
+        with open(txt, 'rt') as fh:
+            txt = fh.read()
+    return txt
+
+
 def generate_flask_config(config):
     """Generate the configuration to deal with Flask.
 
@@ -32,6 +49,10 @@ def generate_flask_config(config):
         key.upper(): value for key, value in config['flask'].items()}
     flask_config.update(user_flask_config)
 
+    for key in ['LOGIN_INSTRUCTIONS', 'SIGN_UP_INSTRUCTIONS',
+                'PRIVACY_POLICY_PAGE']:
+        flask_config[key] = _read_if_html_path(flask_config[key])
+
     database_config = config['sqlalchemy']
     flask_config['SQLALCHEMY_DATABASE_URI'] = \
         ('{}://{}:{}@{}:{}/{}'
